pub enum Data {
TextValue(String),
NumberValue(i64),
BooleanValue(bool),
DoubleValue(f64),
}Expand description
The actual value, which can be one of string, 64 bit signed integer, boolean or 64 bits floating point
Variants
TextValue(String)
The text value
NumberValue(i64)
The (64 bits) integer value
BooleanValue(bool)
The boolean value
DoubleValue(f64)
The (64 bits) floating point value
Implementations
Sourceimpl Data
impl Data
Sourcepub fn merge<B>(
field: &mut Option<Data>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<Data>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.