pub struct Event {
pub message_identifier: String,
pub aggregate_identifier: String,
pub aggregate_sequence_number: i64,
pub aggregate_type: String,
pub timestamp: i64,
pub payload: Option<SerializedObject>,
pub meta_data: HashMap<String, MetaDataValue>,
pub snapshot: bool,
}Expand description
Message containing the information of an Event
Fields
message_identifier: StringThe unique identifier of this event
aggregate_identifier: StringThe identifier of the Aggregate instance that published this event, if any
aggregate_sequence_number: i64The sequence number of the Event in the Aggregate instance that published it, if any
aggregate_type: StringThe Type of the Aggregate instance that published this Event, if any
timestamp: i64The timestamp of the Event
payload: Option<SerializedObject>The Payload of the Event
meta_data: HashMap<String, MetaDataValue>The Meta Data of the Event
snapshot: boolFlag indicating whether the Event is a snapshot Event