pub trait QueryContext { }Expand description
Marker trait that describes the context for a query handler.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait QueryContext { }Marker trait that describes the context for a query handler.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".